Changelog
=========


Version 0.2.0
-------------

Released on Jul 1st 2016

- Added a crude quick example.
- Added all tests to the global package.
- Added API documentation (skeleton).
- Added changelog documentation.
- Added the ability to fail `soft`.
- Updated to have no more strict Sphinx builds.
- Updated tox testing environment.
- After extended use of `0.1.3` I deemed this project ready for it's `0.2` phase.

Version 0.1.3
-------------

Released on Feb 11th 2016

- Added `InstanceOf`.
- Added `Regex`.
- Added `DateTime`.
- Added `Date`.
- Added `Email`.
- Added `Upload` (based on `poort.FileStorage`).
- Updated requirements.

Version 0.1.2
-------------

Released on Feb 7th 2016

- Added `sanitize` filter.
- Updated to include better error reporting.
- Updated names of tests (from `string_field` to `String`).
- Updated tests to have better code coverage.

Version 0.1.1
-------------

Released on Feb 4th 2016

- Fixed sorting bug (Python 3).

Version 0.1.0
-------------

Released on Feb 4th 2016

- Initial release
